Scales input data to the palette, so that colour is mapped linearly to the range of values.
Usage
d_pal(x, pal = hcl.colors(84))
data_pal(x, pal = hcl.colors(84))Scales input data to the palette, so that colour is mapped linearly to the range of values.
d_pal(x, pal = hcl.colors(84))
data_pal(x, pal = hcl.colors(84))