| dirty_pal | R Documentation |
From AAD underway facility (DiRT).
dirty_pal(x, palette = FALSE, alpha = 1)
x |
a vector of data values or a single num (n) |
palette |
logical, if |
alpha |
0 to 1 for transparency |
The palette functions operate in 3 modes: 1) n colours - Pal(6) - returns 6 colours from the palette 2) data - Pal(c(-4000, -2000, 100)) - return colours for 3 elevations 3) palette - Pal(palette = TRUE) - return the full palette and breaks
The palette spans -8000 to 1000 metres, values outside that range clamp to the end colours.
colours, palette, or function, see Details
dirty_pal(seq(-8000, 0, length.out = 10))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.